@@ -5,11 +5,11 @@ Python wrapper for the Hyena API [https://api.hyenabot.xyz/]
 
 # Variables
 __title__ = "hyena"
-__version__ = "1.0.1"
+__version__ = "1.1.0"
 __license__ = "GNU General Public License v3.0"
 __copyright__ = "Copyright (c) 2021-PRESENT AHiddenDonut"
 __author__ = "AHiddenDonut"
 
 # Importing the stuff
-from .client import Client
+from . import Sync, Async
 from . import exceptions
